/* xmms.c
 * Interface to xmms
 *
 * Copyright (C) 2002 Andy Goth <unununium@openverse.com>
 * For more information visit http://ioioio.net/devel/xpyre/
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,
 * USA.
 */

#include <pthread.h>
#include <xmms/configfile.h>
#include <xmms/plugin.h>
#include <xmms/xmmsctrl.h>
#include "xpyre.h"

/* Prototypes */
VisPlugin* get_vplugin_info(void);
static void init(void);
static void cleanup(void);
/*static void about(void);
static void configure(void);
static void start(void);
static void stop(void);*/
static void pcm(gint16 data[2][512]);

/* The current pcm audio data */
gint16 pcm_data[512];

/* This is passed to xmms to register the plugin */
static VisPlugin xpyre = {
/* handle */	NULL,		/* Filled by xmms */
/* filename */	NULL,		/* Filled by xmms */
/* session */	0,		/* Filled by xmms */
/* desc */	"xpyre",
/* pcm_chs */	1,
/* freq_chs*/	0,
/* init */	init,
/* cleanup */	cleanup,
/* about */	NULL,
/* configure */	NULL,
/* disable */	NULL,		/* Filled by xmms */
/* start */	NULL,
/* stop */	NULL,
/* pcm */	pcm,
/* freq */	NULL
};

/* Thread for the main loop */
static pthread_t thread;

/* xmms calls these functions for various reasons */
VisPlugin* get_vplugin_info(void) {return &xpyre;}
void init(void) {pthread_create(&thread, NULL, main_loop, NULL);}
void cleanup(void) {pthread_cancel(thread);}
/*void about(void) {printf("about\n");}
void configure(void) {printf("configure\n");}
void start(void) {}
void stop(void) {}*/
void pcm(gint16 data[2][512]) {memcpy(pcm_data, data[0], sizeof(gint16) * 512);}

/* Interface to standard xmms functions */
void quit(void) {xpyre.disable_plugin(&xpyre);}
void previous_track(void) {xmms_remote_playlist_prev(xpyre.xmms_session);}
void play_track(void) {xmms_remote_play(xpyre.xmms_session);}
void pause_track(void) {xmms_remote_pause(xpyre.xmms_session);}
void stop_track(void) {xmms_remote_stop(xpyre.xmms_session);}
void next_track(void) {xmms_remote_playlist_next(xpyre.xmms_session);}

void load_config(config_t* c)
{
	char name[256];
	ConfigFile* f;
	fix_filename_path(name, "~/.xmms/config", 256);

	f = xmms_cfg_open_file(name);
	if (f == NULL) return;

	xmms_cfg_read_int(f, "xpyre", "width", &c->width);
	xmms_cfg_read_int(f, "xpyre", "height", &c->height);
	/* xmms_cfg_read_int(f, "xpyre", "fullscreen", &c->fullscreen); */
	xmms_cfg_read_int(f, "xpyre", "fps", &c->fps);

	xmms_cfg_free(f);
}

int update_track(track_t* t)
{
	int num = xmms_remote_get_playlist_pos(xpyre.xmms_session);
	if (num == t->num) return 0;

	t->num = num;
	t->title = xmms_remote_get_playlist_title(xpyre.xmms_session, num);
	return 1;
}
